@@ -2,25 +2,13 @@ require 'spec_helper'
 
 describe 'vswitch::ovs' do
 
-  let :default_params do {
-    :package_ensure    => 'present',
-    :enable_hw_offload => false,
-    :disable_emc       => false,
-  }
-  end
-
   shared_examples_for 'vswitch::ovs' do
     context 'default parameters' do
-      let (:params) { default_params }
 
       it 'contains the ovs class' do
         is_expected.to contain_class('vswitch::ovs')
       end
 
-      it 'contains params' do
-        is_expected.to contain_class('vswitch::params')
-      end
-
       it 'clears hw-offload option' do
         is_expected.to contain_vs_config('other_config:hw-offload').with(
           :ensure => 'absent', :restart => true, :wait => true,
@@ -44,21 +32,23 @@ describe 'vswitch::ovs' do
           :ensure => true,
           :enable => true,
           :name   => platform_params[:ovs_service_name],
+          :tag    => 'openvswitch'
         )
       end
 
       it 'install package' do
-        is_expected.to contain_package(platform_params[:ovs_package_name]).with(
+        is_expected.to contain_package('openvswitch').with(
           :name   => platform_params[:ovs_package_name],
-          :ensure => params[:package_ensure],
-          :before => 'Service[openvswitch]'
+          :ensure => 'present',
+          :before => 'Service[openvswitch]',
+          :tag    => 'openvswitch'
         )
       end
 
       it 'restarts the service when needed' do
         is_expected.to contain_exec('restart openvswitch').with(
           :path        => ['/sbin', '/usr/sbin', '/bin', '/usr/bin'],
-          :command     => "systemctl -q restart %s.service" % platform_params[:ovs_service_name],
+          :command     => ['systemctl', '-q', 'restart', "#{platform_params[:ovs_service_name]}.service"],
           :refreshonly => true
         )
       end
@@ -74,10 +64,11 @@ describe 'vswitch::ovs' do
         }
       end
       it 'installs correct package' do
-        is_expected.to contain_package(platform_params[:ovs_package_name]).with(
+        is_expected.to contain_package('openvswitch').with(
           :name   => platform_params[:ovs_package_name],
           :ensure => 'latest',
-          :before => 'Service[openvswitch]'
+          :before => 'Service[openvswitch]',
+          :tag    => 'openvswitch'
         )
       end
       it 'configures hw-offload option' do
@@ -114,20 +105,17 @@ describe 'vswitch::ovs' do
             {
               :ovs_package_name  => 'openvswitch-switch',
               :ovs_service_name  => 'openvswitch-switch',
-              :provider          => 'ovs',
             }
           elsif facts[:os]['name'] == 'Ubuntu'
             {
               :ovs_package_name  => 'openvswitch-switch',
               :ovs_service_name  => 'openvswitch-switch',
-              :provider          => 'ovs',
             }
           end
         when 'RedHat'
           {
             :ovs_package_name => 'openvswitch',
             :ovs_service_name => 'openvswitch',
-            :provider         => 'ovs_redhat',
           }
         end
       end
